@@ -42,7 +42,7 @@ class ArchiveModel: public QAbstractItemModel
 {
     Q_OBJECT
 public:
-    ArchiveModel(const QString &dbusPathName, QObject *parent = 0);
+    explicit ArchiveModel(const QString &dbusPathName, QObject *parent = 0);
     ~ArchiveModel();
 
     QVariant data(const QModelIndex &index, int role) const;
